@@ -1,5 +1,5 @@
 package Lingua::EN::Syllable;
-$Lingua::EN::Syllable::VERSION = '0.28';
+$Lingua::EN::Syllable::VERSION = '0.29';
 # ABSTRACT: count the number of syllables in English words
 
 use 5.006;
@@ -139,9 +139,22 @@ Contractions are not well supported.
 Compound words (like "lifeboat"), where the first word ends in a silent 'e'
 are counted with an extra syllable.
 
+=head1 SEE ALSO
+
+L<Lingua::Phonology> - a framework of classes that provide
+"an object model for lingistic phonology and sound change".
+That includes syllables, and it looks like you can use it to
+get syllables for words, but from a quick skim of the doc I
+can't see exactly how.
+
+L<Text::Info> - a new module (as of late 2015) that provides
+information about text in Germanic languages,
+including syllable count.
+
+
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Lingua-EN-Syllable>
+L<https://github.com/neilb/Lingua-EN-Syllable>
 
 =head1 COPYRIGHT AND LICENSE
 
